@@ -3,7 +3,7 @@ package Task::Padre::Plugins;
 use warnings;
 use strict;
 
-our $VERSION = '0.18';
+our $VERSION = '0.19';
 
 1;
 __END__
@@ -32,6 +32,10 @@ Alarm Clock (Audio::Beep)
 
 reformat your text within Padre  
 
+=haed2 Padre::Plugin::Catalyst
+
+Simple Catalyst helper interface for Padre
+
 =head2 Padre::Plugin::CommandLine
 
 vi and emacs in Padre?
@@ -46,6 +50,10 @@ use CSS::Minifier::XS to minify css
 
 use WebService::Validator::CSS::W3C to validate the CSS
 
+=head2 Padre::Plugin::DataWalker
+
+Simple Perl data structure browser Padre
+
 =head2 Padre::Plugin::Encode
 
 convert file to different encoding in Padre
